drop table if exists hermes;
create table if not exists hermes
(
    id           bigint auto_increment comment 'id',
    identifier   varchar(32)  not null comment '账户标识',
    nick_name    varchar(128) null comment '昵称',
    face_url     varchar(512) null comment '头像',
    account_type int(3)       not null comment '账号类型 1:B端 2:C端  99:系统账号',
    user_id      bigint       not null comment '用户id C端为会员号',
    state        int(3)       not null comment '账号状态 1:正常 2:封禁 3:其他',
    create_time  datetime     null comment '创建时间',
    create_day   date         not null comment '创建日期(方便建立索引和统计)',
    update_time  datetime     null comment '修改时间',
    constraint hermes_pk
        primary key (id)
)
    comment '用户账号信息';

create index hermes_create_day_index
    on hermes (create_day);

create unique index hermes_identifier_uindex
    on hermes (identifier);

create unique index hermes_user_id_uindex
    on hermes (user_id, account_type);


drop table if exists group_info;
create table if not exists group_info
(
    id            bigint auto_increment,
    group_name    varchar(128)  null comment '群名称',
    group_summary varchar(4000) null comment '群简介',
    group_type    int(3)        not null comment '群组类型 1:系统群 2:用户群',
    max_user      int           null comment '最大人数',
    create_time   datetime      not null comment '创建时间',
    update_time   datetime      null comment '修改时间',
    constraint group_info_pk
        primary key (id)
)
    comment '群组信息(todo)';


drop table if exists group_user;
create table if not exists group_user
(
    id              bigint auto_increment,
    group_id        bigint        not null comment '群id',
    account_id      varchar(64)   not null comment '账号的identifier',
    identity        int(4)        not null comment '账号在所属群的身份 1:普通成员 2:管理员 3:群主',
    user_group_nick varchar(64)   null comment '用户群昵称',
    group_show_name varchar(2000) null comment '群名展示 为空则取群名',
    join_time       datetime      not null comment '加入时间',
    join_day        date          null comment '加入日期',
    constraint group_user_pk
        primary key (id)
)
    comment '群人员';

create unique index group_user_group_id_account_id_uindex
    on group_user (group_id, account_id);


drop table if exists sys_platform;
create table if not exists sys_platform
(
    id            int auto_increment,
    platform_type int(3)       not null comment '平台类型',
    platform_code varchar(32)  null comment '平台码',
    platform_name varchar(128) null comment '平台名称',
    constraint sys_platform_pk
        primary key (id)
)
    comment '系统平台';

create unique index sys_platform_platform_code_uindex
    on sys_platform (platform_code);



drop table if exists message_history;
create table if not exists message_history
(
    id                bigint        not null comment 'id'
        primary key,
    msg_summary       varchar(64)   null comment '消息内容描述',
    msg_status        int(3)        null comment '发送状态 1:待发 2:已上发 3:发送成功 4:发送失败',
    msg_status_desc   varchar(2000) null comment '状态描述',
    msg_topic         varchar(512)  null comment '消息的topic',
    to_account        varchar(255)  null comment '目标账号',
    from_account      varchar(255)  null comment '发送方账号',
    need_result       tinyint(1)    null comment '需要结果',
    msg_life_time     datetime      null comment '消息截止发送时间',
    send_time         datetime      null comment '发送时间',
    send_day          date          null comment '发送日期',
    send_success_time datetime      null comment '推送成功时间',
    create_time       datetime      not null comment '创建时间',
    update_time       datetime      null comment '修改时间'
) comment '消息记录';
create index message_history_to_account_index
    on message_history (to_account);
create index message_history_msg_status_index
    on message_history (msg_status);
create index message_history_send_day_index
    on message_history (send_day);


drop table if exists message_data;
create table if not exists message_data
(
    id          bigint auto_increment comment 'id'
        primary key,
    msg_id      bigint          not null comment '消息id',
    type        int(3)          null comment '消息类型 1:文本消息 2:图片 3:语音 4:视频 5:表情 6:地理位置 9:自定义',
    data        text            null comment '自定义消息传递的信息',
    text        varchar(2000)   null comment '文本消息的内容/地理位置消息的地址描述',
    image_url   varchar(4000)   null comment '图片消息的图片地址,"{0},{1},{2}" 依次为缩略图、中图、原图',
    emoji_index int             null comment '表情消息 表情下标',
    lat         decimal(18, 10) null comment '纬度 地理位置消息专用',
    lng         decimal(18, 10) null comment '经度 地理位置消息专用',
    voice_url   varchar(2000)   null comment '语音消息 语音地址',
    video_url   varchar(2000)   null comment '视频消息视频地址"{0},{1}" 依次为封面图、视频播放地址',
    duration    int             null comment '语音、视频消息对应资源的时(秒)'
) comment '消息详情';
create index message_data_msg_id_index
    on message_data (msg_id);


drop table if exists sys_topic;
create table if not exists sys_topic
(
    id         bigint auto_increment primary key,
    topic      varchar(64)   not null comment '主题',
    topic_desc varchar(2000) null comment '主题描述',
    preset     tinyint(1)    null comment '是否是默认的 默认的topic不需要接口返回',
    yn         tinyint(1)    not null comment '是否启用'
) comment '消息主题';

create unique index sys_topic_topic_uindex
    on sys_topic (topic);


create table if not exists disturb_setting
(
    id            bigint auto_increment,
    user_id       bigint      not null comment '用户id',
    platform_code varchar(32) not null comment '平台code',
    enabled       tinyint(1)  null comment '是否启用',
    start_time    varchar(8)  null comment '勿扰开始时间',
    end_time      varchar(8)  null comment '勿扰结束时间',
    constraint disturb_setting_pk
        primary key (id)
)
    comment '勿扰设置';

create unique index disturb_setting_user_id_platform_code_uindex
    on disturb_setting (user_id, platform_code);

create table if not exists app_update_msg
(
    `id`            bigint        not null,
    `platform_code` varchar(32)   not null comment '平台码',
    `status`        int(3)        not null comment '发送状态',
    `remark`        varchar(255)  not null comment '备注',
    `update_remark` varchar(2048) not null comment '更新日志',
    `force_upload`  tinyint(1)    not null comment '强制更新',
    `target_url`    varchar(2048) null comment '下载地址',
    `version_code`  int(11)       not null comment '版本号',
    `version_name`  varchar(256)  null comment '版本名称',
    `md5`           varchar(64)   null comment 'md5码',
    `file_size`     int(11)       null comment '文件大小',
    `latest`        tinyint(1)    not null comment '最新版',
    `create_time`   datetime      not null comment '创建时间',
    `update_time`   datetime      null comment '修改时间',
    constraint app_update_msg_pk
        primary key (id)
)
    comment '应用更新消息';

alter table app_update_msg
    modify id int auto_increment;

create index app_update_msg_version_code_index
    on app_update_msg (version_code);
create index app_update_msg_platform_code_index
    on app_update_msg (platform_code);




