package cn.fw.hermes.common.utils

import cn.hutool.http.HttpUtil
import cn.hutool.json.JSONUtil
import org.apache.commons.codec.binary.Base64
import java.net.URLEncoder
import java.nio.charset.StandardCharsets
import java.util.*
import javax.crypto.Mac
import javax.crypto.spec.SecretKeySpec

/**
 * 机器人工具
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 机器人工具
 * @date : 2023-09-08 14:40
 */
object RobotHelper {
    private const val DING_TALK_ROBOT_API = "https://oapi.dingtalk.com/robot/send"

    @Throws(Exception::class)
    fun sendEarlyWarning(accessToken: String?, secret: String?): String {
        val timestamp = System.currentTimeMillis()
        val sign = createSign(timestamp, secret ?: "")
        val url = String.format("%s?access_token=%s&timestamp=%s&sign=%s", DING_TALK_ROBOT_API, accessToken, timestamp, sign)

        val markdown: MutableMap<String, String> = HashMap()
        markdown["title"] = "预警信息"
        markdown["text"] = """### MQTT服务断开连接
 ##### 重连次数超过10次
 ###### ${DateUtil.getFormatString(Date(), "MM月dd日 HH点mm分")} 发布
"""

        val params: MutableMap<String, Any> = HashMap()
        params["msgtype"] = "markdown"
        params["markdown"] = markdown
        val post = HttpUtil.createPost(url)
        post.body(JSONUtil.toJsonStr(params), "application/json")

        return post.setConnectionTimeout(-1).execute().body()
    }

    @Throws(Exception::class)
    private fun createSign(timestamp: Long, secret: String): String {
        val stringToSign = """
            $timestamp
            $secret
            """.trimIndent()
        val mac = Mac.getInstance("HmacSHA256")
        mac.init(SecretKeySpec(secret.toByteArray(StandardCharsets.UTF_8), "HmacSHA256"))
        val signData = mac.doFinal(stringToSign.toByteArray(StandardCharsets.UTF_8))
        return URLEncoder.encode(String(Base64.encodeBase64(signData)), "UTF-8")
    }
}
