package cn.fw.hermes.domain.db;

import cn.fw.common.data.entity.BaseAuditableTimeEntity;
import cn.fw.common.web.serializer.LocalDateTimeSerializerProcessor;
import cn.fw.hermes.domain.enums.AccountStateEnum;
import cn.fw.hermes.domain.enums.AccountTypeEnum;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.time.LocalDate;

/**
 * 账户信息
 *
 * @author : kurisu
 * @version : 2.0
 * @className : Hermes
 * @description : 账户信息
 * @date : 2023-06-20 16:03
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class Hermes extends BaseAuditableTimeEntity<Hermes, Long> {
    /**
     * 用户识别码
     */
    private String identifier;
    /**
     * 用户昵称
     */
    private String nickName;
    /**
     * 头像URL
     */
    private String faceUrl;
    /**
     * 账户类型 1：表示B端，2表示C端
     */
    private AccountTypeEnum accountType;
    /**
     * 用户ID
     */
    private Long userId;
    /**
     * 账户状态，1:正常 2:封禁
     */
    private AccountStateEnum state;
    /**
     * 信鸽设备token
     */
    private String xgToken;
    /**
     * 创建日期
     */
    @JsonDeserialize(using = LocalDateTimeSerializerProcessor.LocalDateDeserializer.class)
    @JsonSerialize(using = LocalDateTimeSerializerProcessor.LocalDateSerializer.class)
    private LocalDate createDay;
}
