package cn.fw.hermes.domain.db;

import cn.fw.common.data.entity.BaseEntity;
import cn.fw.common.data.mybatis.handler.StringListTypeHandler;
import cn.fw.hermes.domain.enums.MsgTypeEnum;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.math.BigDecimal;
import java.util.List;

/**
 * 消息详情
 *
 * @author : kurisu
 * @version : 2.0
 * @className : MessageData
 * @description : 消息详情
 * @date : 2023-06-21 15:12
 */
@TableName(autoResultMap = true)
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class MessageData extends BaseEntity<MessageData, Long> {
    /**
     * 消息id
     */
    private Long msgId;
    /**
     * 消息类型
     */
    private MsgTypeEnum type;
    /**
     * 消息内容[自定义消息专用]
     */
    private String data;
    /**
     * 文本消息的内容/地理位置消息的地址描述
     */
    private String text;
    /**
     * 图片消息的图片地址
     * [0,1,2] 依次为缩略图、中图、原图
     */
    @TableField(typeHandler = StringListTypeHandler.class)
    private List<String> imageUrl;
    /**
     * 表情消息 表情下标
     */
    private Integer emojiIndex;
    /**
     * 纬度 地理位置消息专用
     */
    private BigDecimal lat;
    /**
     * 经度 地理位置消息专用
     */
    private BigDecimal lng;
    /**
     * 语音消息 语音地址
     */
    private String voiceUrl;
    /**
     * 视频消息视频地址
     * [0,1]依次为封面图、视频播放地址
     */
    @TableField(typeHandler = StringListTypeHandler.class)
    private List<String> videoUrl;
    /**
     * 语音、视频消息对应资源的时长(秒)
     */
    private Integer duration;
}
