package cn.fw.hermes.domain.dto;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * 消息体
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息体
 * @date : 2023-07-22 16:27
 */
@Data
public class MessageBodyDTO implements Serializable {
    private static final long serialVersionUID = 84993841L;
    /**
     * 消息类型
     *
     * @see cn.fw.hermes.domain.enums.MsgTypeEnum
     */
    private Integer type;
    /**
     * 消息内容[自定义消息专用]
     */
    private String data;
    /**
     * 文本消息的内容/地理位置消息的地址描述
     */
    private String text;
    /**
     * 图片消息的图片地址
     * [0,1,2] 依次为缩略图、中图、原图
     */
    private List<String> imageUrl;
    /**
     * 表情消息 表情下标
     */
    private Integer emojiIndex;
    /**
     * 纬度 地理位置消息专用
     */
    private BigDecimal lat;
    /**
     * 经度 地理位置消息专用
     */
    private BigDecimal lng;
    /**
     * 语音消息 语音地址
     */
    private String voiceUrl;
    /**
     * 视频消息视频地址
     * [0,1]依次为封面图、视频播放地址
     */
    private List<String> videoUrl;
    /**
     * 语音、视频消息对应资源的时长(秒)
     */
    private Integer duration;
}
