package cn.fw.hermes.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * 账号状态枚举
 *
 * @author : kurisu
 * @version : 2.0
 * @className : AccountStateEnum
 * @description : 账号状态枚举
 * @date : 2023-06-20 16:06
 */
public enum AccountStateEnum implements IEnum<Integer> {
    NORMAL(1, "正常"),
    BLOCKED(2, "封禁"),
    ;


    /**
     * 值
     */
    private final Integer value;
    /**
     * 类型
     */
    @Getter
    private final String name;

    AccountStateEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static AccountStateEnum ofValue(final Integer value) {
        for (final AccountStateEnum typeEnum : AccountStateEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final AccountStateEnum typeEnum : AccountStateEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }
}
