package cn.fw.hermes.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * 消息状态
 */
public enum MsgStatusEnum implements IEnum<Integer> {
    WAITING(1, "待发送"),
    UPLOAD(2, "已上传到MQTT"),
    SUCCESS(3, "发送成功"),
    FAIL(4, "发送失败"),
    ;


    /**
     * 值
     */
    private final Integer value;
    /**
     * 类型
     */
    @Getter
    private final String name;

    MsgStatusEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static MsgStatusEnum ofValue(final Integer value) {
        for (final MsgStatusEnum typeEnum : MsgStatusEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final MsgStatusEnum typeEnum : MsgStatusEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }
}
