package cn.fw.hermes.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * 消息类型
 */
public enum PlatformTypeEnum implements IEnum<Integer> {
    APP(1, "app端"),
    WEB(2, "pc管理端"),
    REPORT(3, "报表端"),
    H5(4, "h5端"),
    MINI(5, "小程序端"),
    EVO(6, "出行app端"),
    ;


    /**
     * 值
     */
    private final Integer value;
    /**
     * 类型
     */
    @Getter
    private final String name;

    PlatformTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static PlatformTypeEnum ofValue(final Integer value) {
        for (final PlatformTypeEnum typeEnum : PlatformTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final PlatformTypeEnum typeEnum : PlatformTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}
