package cn.fw.hermes.rpc.ehr;

import cn.fw.common.cache.CacheExtender;
import cn.fw.data.base.domain.common.Message;
import cn.fw.ehr.sdk.api.StaffApi;
import cn.fw.ehr.sdk.api.result.StaffInfo;
import cn.fw.hermes.common.constant.Constant;
import cn.fw.hermes.common.utils.StringUtils;
import cn.fw.hermes.rpc.ehr.dto.StaffInfoDTO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.lang.Nullable;
import org.springframework.stereotype.Service;

import java.util.Objects;

/**
 * @author : kurisu
 * @className : EhrRpcService
 * @description : 人事
 * @date: 2021-01-19 17:34
 */
@Slf4j
@Service
@RequiredArgsConstructor
public class EhrRpcService {
    private final StaffApi staffApi;
    private final CacheExtender cache;


    @Nullable
    public StaffInfoDTO queryStaffInfo(final Long userId) {
        String keyName = Constant.RPC_EHR_CACHE_KEY.apply("user");
        if (userId == null) {
            return null;
        }
        try {
            StaffInfoDTO infoDTO = cache.getCache(keyName, userId, StaffInfoDTO.class);
            if (Objects.nonNull(infoDTO)) {
                return infoDTO;
            }
            final Message<StaffInfo> msg = staffApi.getStaffInfoById(userId);
            log.info("StaffApi.queryStaffInfo: msg.code={}, msg.result={}, msg.data={}", msg.getCode(), msg.getResult(), msg.getData());
            if (msg.isSuccess() && !Objects.isNull(msg.getData())) {
                final StaffInfoDTO staffInfoDTO = new StaffInfoDTO();
                BeanUtils.copyProperties(msg.getData(), staffInfoDTO);
                cache.putCache(keyName, userId, staffInfoDTO);
                return staffInfoDTO;
            }
        } catch (Exception e) {
            log.error("queryStaffInfo 失败", e);
        }
        return null;
    }

    @Nullable
    public StaffInfoDTO queryStaffInfoByMobile(final String mobile) {
        String keyName = Constant.RPC_EHR_CACHE_KEY.apply("mobile");
        if (StringUtils.isEmpty(mobile)) {
            return null;
        }
        try {
            StaffInfoDTO infoDTO = cache.getCache(keyName, mobile, StaffInfoDTO.class);
            if (Objects.nonNull(infoDTO)) {
                return infoDTO;
            }
            final Message<StaffInfo> msg = staffApi.getStaffInfoByMobile(mobile);
            log.info("StaffApi.queryStaffInfoByMobile: msg.code={}, msg.result={}, msg.data={}", msg.getCode(), msg.getResult(), msg.getData());
            if (msg.isSuccess() && !Objects.isNull(msg.getData())) {
                final StaffInfoDTO staffInfoDTO = new StaffInfoDTO();
                BeanUtils.copyProperties(msg.getData(), staffInfoDTO);
                cache.putCache(keyName, mobile, staffInfoDTO);
                return staffInfoDTO;
            }
        } catch (Exception e) {
            log.error("queryStaffInfoByMobile 失败", e);
        }
        return null;
    }
}
