package cn.fw.hermes.rpc.member

import cn.fw.common.util.logError
import cn.fw.common.util.logInfo
import cn.fw.hermes.rpc.member.dto.MemberUserDTO
import cn.fw.member.sdk.api.MemberApi
import org.springframework.stereotype.Service

/**
 * 会员服务
 *
 * @author kurisu
 */
@Service
class MemberRpcService(
    private val memberApi: MemberApi
) {
    /**
     * 根据会员ID获取会员信息
     *
     * @param userId 会员ID
     * @return 会员信息
     */
    fun user(userId: Long?): MemberUserDTO? {
        try {
            userId?.let {
                memberApi.getMemberById(userId)?.takeIf {
                    logInfo("调用Member系统[根据会员ID[{}]获取会员信息] --> res:{}  data:{}", userId, it.result, it.data)
                    it.isSuccess
                }?.run {
                    data?.let {
                        MemberUserDTO(
                            latestAccountId = data.latestAccountId,
                            realName = data.realName,
                            credentType = data.credentType,
                            credentNo = data.credentNo,
                            birthday = data.birthDate,
                            accountId = data.latestAccountId,
                        )
                    }
                }
            }
        } catch (e: Exception) {
            logError("调用Member[根据会员ID[{}]获取会员信息]系统失败", userId, e)
        }
        return null
    }
}
