package cn.fw.hermes.sdk.v2.para;

import cn.fw.common.validator.EnumValue;
import cn.fw.hermes.sdk.v2.enums.Platform;
import lombok.Data;
import org.hibernate.validator.constraints.ScriptAssert;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;

/**
 * 应用更新消息
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 应用更新消息
 * @date : 2023-08-14 10:34
 */
@Data
@ScriptAssert.List({
    @ScriptAssert(lang = "javascript", script = "_this.checkTarget()", message = "下载地址不能为空"),
    @ScriptAssert(lang = "javascript", script = "_this.checkMd5()", message = "md5值不能为空"),
    @ScriptAssert(lang = "javascript", script = "_this.checkFileSize()", message = "文件大小不能为空"),
})
public class AppUpdateMsgCondition {
    /**
     * 平台
     *
     * @see cn.fw.hermes.sdk.v2.enums.Platform
     */
    @NotNull(message = "平台类型不能为空")
    @EnumValue(enumClass = cn.fw.hermes.sdk.v2.enums.Platform.class, message = "平台类型不正确")
    private Integer platform;
    @NotBlank(message = "更新日志不能为空")
    private String updateRemark;
    /**
     * 强制更新
     */
    private Boolean forceUpload;

    private String targetUrl;

    @NotNull(message = "版本号不能为空")
    private Integer versionCode;

    private String versionName;

    private String md5;

    private Integer fileSize;

    public boolean checkTarget() {
        if (Platform.APP.getValue().equals(platform)) {
            return targetUrl != null && !targetUrl.isEmpty();
        }
        return true;
    }

    public boolean checkMd5() {
        if (Platform.APP.getValue().equals(platform)) {
            return md5 != null && !md5.isEmpty();
        }
        return true;
    }

    public boolean checkFileSize() {
        if (Platform.APP.getValue().equals(platform)) {
            return fileSize != null && fileSize > 0;
        }
        return true;
    }
}
