package cn.fw.hermes.sdk.v2.para;


import java.io.Serializable;
import java.util.Objects;

/**
 * 可变对值
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 由两个元素组成的可变对值。
 * @date : 2023-07-22 10:10
 */
public class HermesPair<L, R> implements Serializable {
    private static final long serialVersionUID = 454918890077093841L;

    public L left;
    public R right;

    public HermesPair() {
        super();
    }

    public HermesPair(L left, R right) {
        super();
        this.left = left;
        this.right = right;
    }

    public static <L, R> HermesPair<L, R> of(L left, R right) {
        return new HermesPair<>(left, right);
    }

    public L getLeft() {
        return left;
    }


    public R getRight() {
        return right;
    }

    public void setLeft(L left) {
        this.left = left;
    }

    public void setRight(R right) {
        this.right = right;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        HermesPair<?, ?> that = (HermesPair<?, ?>) o;
        return Objects.equals(left, that.left) && Objects.equals(right, that.right);
    }

    @Override
    public int hashCode() {
        return (getLeft() == null ? 0 : getLeft().hashCode()) ^
                (getRight() == null ? 0 : getRight().hashCode());
    }

    @Override
    public String toString() {
        return "(" + getLeft() + ',' + getRight() + ')';
    }

    /**
     * <p>使用给定格式格式化接收器。</p>
     *
     * <p>使用 {@link java.util.Formattable} 执行格式化。可以使用两个变量来嵌入左右元素。
     * 使用 {@code %1$s} 左侧元素（键）和 {@code %2$s} 右侧元素（值）。
     * 使用 {@code toString()} 的默认格式为 {@code (%1$s,%2$s)}。</p>
     *
     * @param format 格式字符串，可选地包含 {@code %1$s} 和 {@code %2$s}，不为空。
     * @return 格式化字符串，不为 null
     */
    public String toString(final String format) {
        return String.format(format, getLeft(), getRight());
    }

}
