package cn.fw.hermes.sdk.v2.para;


import java.io.Serializable;
import java.util.Objects;

/**
 * 可变三元组。
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 由三个元素组成的可变三元组。
 * @date : 2023-07-22 10:35
 */
public class HermesTriple<L, M, R> implements Serializable {
    private static final long serialVersionUID = -1L;
    public L left;
    public M middle;
    public R right;

    public HermesTriple() {
        super();
    }

    public HermesTriple(final L left, final M middle, final R right) {
        super();
        this.left = left;
        this.middle = middle;
        this.right = right;
    }

    public static <L, M, R> HermesTriple<L, M, R> of(final L left, final M middle, final R right) {
        return new HermesTriple<>(left, middle, right);
    }

    public L getLeft() {
        return left;
    }


    public M getMiddle() {
        return middle;
    }


    public R getRight() {
        return right;
    }

    public void setLeft(L left) {
        this.left = left;
    }

    public void setMiddle(M middle) {
        this.middle = middle;
    }

    public void setRight(R right) {
        this.right = right;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        HermesTriple<?, ?, ?> that = (HermesTriple<?, ?, ?>) o;
        return Objects.equals(left, that.left) && Objects.equals(middle, that.middle) && Objects.equals(right, that.right);
    }

    @Override
    public int hashCode() {
        return (getLeft() == null ? 0 : getLeft().hashCode()) ^
                (getMiddle() == null ? 0 : getMiddle().hashCode()) ^
                (getRight() == null ? 0 : getRight().hashCode());
    }

    @Override
    public String toString() {
        return "(" + getLeft() + "," + getMiddle() + "," + getRight() + ")";
    }

    /**
     * <p>使用给定格式格式化接收器。</p>
     *
     * <p>使用 {@link java.util.Formattable} 执行格式化。可以使用三个变量来嵌入左右元素。
     * 使用 {@code %1$s} 左侧元素、{@code %2$s}中间元素和 {@code %3$s} 右侧元素。
     * 使用 {@code toString()} 的默认格式为 {@code (%1$s,%2$s,%3$s)}。</p>
     *
     * @param format 格式字符串，可选地包含 {@code %1$s} 、{@code %2$s}和 {@code %3$s}，不为空。
     * @return 格式化字符串，不为 null
     */
    public String toString(final String format) {
        return String.format(format, getLeft(), getMiddle(), getRight());
    }
}
