package cn.fw.hermes.sdk.v2.service;

import cn.fw.data.base.domain.common.Message;
import cn.fw.hermes.sdk.v2.para.AccountV2Condition;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 账号相关服务
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 2.0版本的账号服务
 * @date : 2023-07-20 16:15
 */
@FeignClient(value = "fw-hermes", path = "/api/hermes/account")
public interface IAccountV2Service {

    /**
     * 注册账号
     *
     * @param condition 参数
     * @return 结果
     */
    @PostMapping("/register")
    Message<Boolean> register(@RequestBody AccountV2Condition condition);

    /**
     * 获取用户标识码
     *
     * @param userId   用户id
     * @param userType 账号类型 {@link cn.fw.hermes.sdk.v2.enums.AccountType}
     * @return
     */
    @GetMapping("/getIdentifier")
    Message<String> getIdentifier(@RequestParam("userId") Long userId, @RequestParam(value = "userType", defaultValue = "1", required = false) Integer userType);

    /**
     * 踢下线
     *
     * @param userId   用户ID
     * @param userType 账号类型 {@link cn.fw.hermes.sdk.v2.enums.AccountType}
     * @return
     */
    @GetMapping("/kick-out")
    Message<Void> kick(@RequestParam("userId") Long userId, @RequestParam("userType") Integer userType);
}
