package cn.fw.hermes.sdk.v2.service;

import cn.fw.data.base.domain.common.Message;
import cn.fw.hermes.sdk.v2.para.AppUpdateMsgCondition;
import cn.fw.hermes.sdk.v2.para.MsgV2Condition;
import cn.fw.hermes.sdk.v2.result.MessageV2Result;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 消息处理服务
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息处理服务
 * @date : 2023-07-22 14:32
 */
@FeignClient(value = "fw-hermes", path = "/api/hermes/message")
public interface IMessageV2Service {
    /**
     * 异步发送
     * 发送失败时会自动重试
     *
     * @param condition 消息对象
     * @return messageId 消息唯一识别码 用于查询消息发送状态等信息
     */
    @PostMapping("/send/async")
    Message<Long> asyncSendMsg(@RequestBody MsgV2Condition condition);

    /**
     * 同步发送
     * 通过发送失败的情况需要调用方重试
     *
     * @param condition 消息内容
     * @return 消息推送结果
     */
    @PostMapping("/send/sync")
    Message<MessageV2Result> sendMsg(@RequestBody MsgV2Condition condition);

    /**
     * 通过消息id查询消息处理状态
     *
     * @param messageId 消息id
     * @return
     */
    @GetMapping("/result")
    Message<MessageV2Result> queryMsgResult(@RequestParam("messageId") final Long messageId);

    /**
     * 发送应用更新消息
     *
     * @param condition 消息内容
     */
    @PostMapping("/send/update_msg")
    Message<Void> sendUpdateMsg(@RequestBody AppUpdateMsgCondition condition);
}
