package cn.fw.hermes.controller.app;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.common.web.auth.LoginAuthBean;
import cn.fw.common.web.auth.annotation.CurrentUser;
import cn.fw.data.base.domain.common.Message;
import cn.fw.hermes.common.constant.Constant;
import cn.fw.hermes.domain.dto.DisturbSettingDTO;
import cn.fw.hermes.domain.vo.AccountResultVO;
import cn.fw.hermes.domain.vo.DisturbSettingVO;
import cn.fw.hermes.service.biz.AccountBizService;
import cn.fw.hermes.service.biz.DisturbBizService;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.annotation.IgnoreAuth;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

import static cn.fw.common.businessvalidator.Validator.BV;
import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * @author : Kurisu
 * @date : 2021/2/2 11:11
 * @since :2.0
 */
@Validated
@RestController
@RequestMapping("/app/account")
@RequiredArgsConstructor
@Authorization(AuthType.APP)
public class AppAccountController {

    private final AccountBizService accountBizService;
    private final DisturbBizService disturbBizService;

    @IgnoreAuth
    @GetMapping("/topic")
    @ControllerMethod("获取用户主题")
    public Message<AccountResultVO> queryUserTopic(@CurrentUser LoginAuthBean user, HttpServletRequest request) {
        String headerValue = request.getHeader(Constant.PLATFORM_KEY);
        BV.isNotBlank(headerValue, () -> "平台不正确");
        return success(accountBizService.queryStaffTopic(user, headerValue));
    }

    @IgnoreAuth
    @GetMapping("/setting/disturb/detail")
    @ControllerMethod("获取用户勿扰设置")
    public Message<DisturbSettingVO> queryUserSetting(@CurrentUser LoginAuthBean user, HttpServletRequest request) {
        String headerValue = request.getHeader(Constant.PLATFORM_KEY);
        BV.isNotBlank(headerValue, () -> "平台不正确");
        DisturbSettingVO vo = disturbBizService.querySetting(user.getUserId(), headerValue);
        return success(vo);
    }

    @IgnoreAuth
    @PostMapping("/setting/disturb/save")
    @ControllerMethod("修改用户勿扰设置")
    public Message<Void> saveUserSetting(@CurrentUser LoginAuthBean user, HttpServletRequest request, @RequestBody @Validated DisturbSettingDTO setting) {
        String headerValue = request.getHeader(Constant.PLATFORM_KEY);
        BV.isNotBlank(headerValue, () -> "平台不正确");
        disturbBizService.saveUserSetting(user.getUserId(), headerValue, setting);
        return success();
    }
}
