package cn.fw.hermes.controller.erp;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.common.web.auth.LoginAuthBean;
import cn.fw.common.web.auth.annotation.CurrentUser;
import cn.fw.data.base.domain.common.Message;
import cn.fw.hermes.common.constant.Constant;
import cn.fw.hermes.domain.dto.DisturbSettingDTO;
import cn.fw.hermes.domain.vo.DisturbSettingVO;
import cn.fw.hermes.domain.vo.MsgBizTypeVO;
import cn.fw.hermes.service.biz.CommonBizService;
import cn.fw.hermes.service.biz.DisturbBizService;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.annotation.IgnoreAuth;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

import static cn.fw.common.businessvalidator.Validator.BV;
import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * 消息管理
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息管理
 * @date : 2023-07-26 11:22
 */
@Validated
@RestController
@RequestMapping("/erp/common")
@RequiredArgsConstructor
@Authorization(AuthType.ERP)
public class CommonController {
    private final DisturbBizService disturbBizService;
    private final CommonBizService commonBizService;

    @IgnoreAuth
    @GetMapping("/msg/type/all")
    @ControllerMethod("获取所有自定义消息的业务类型")
    public Message<List<MsgBizTypeVO>> getMsgBizTypes() {
        List<MsgBizTypeVO> list = commonBizService.queryMsgBizTypes();
        return success(list);
    }

    @IgnoreAuth
    @PostMapping("/msg/type/save")
    @ControllerMethod("新增自定义消息的业务类型")
    public Message<Void> saveMsgBizType(@RequestParam("type") String type, @RequestParam("typeDesc") String typeDesc) {
        commonBizService.saveMsgBizType(type, typeDesc);
        return success();
    }

    @IgnoreAuth
    @GetMapping("/setting/disturb/detail")
    @ControllerMethod("获取用户勿扰设置")
    public Message<DisturbSettingVO> queryUserSetting(@CurrentUser LoginAuthBean user, HttpServletRequest request) {
        String headerValue = request.getHeader(Constant.PLATFORM_KEY);
        BV.isNotBlank(headerValue, () -> "平台不正确");
        DisturbSettingVO vo = disturbBizService.querySetting(user.getUserId(), headerValue);
        return success(vo);
    }

    @IgnoreAuth
    @PostMapping("/setting/disturb/save")
    @ControllerMethod("修改用户勿扰设置")
    public Message<Void> saveUserSetting(@CurrentUser LoginAuthBean user, HttpServletRequest request, @RequestBody @Validated DisturbSettingDTO setting) {
        String headerValue = request.getHeader(Constant.PLATFORM_KEY);
        BV.isNotBlank(headerValue, () -> "平台不正确");
        disturbBizService.saveUserSetting(user.getUserId(), headerValue, setting);
        return success();
    }
}
