package cn.fw.hermes.controller.erp;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.data.base.domain.common.Message;
import cn.fw.hermes.domain.dto.MsgDebugDTO;
import cn.fw.hermes.domain.vo.MessageBody;
import cn.fw.hermes.domain.vo.MessageDetail;
import cn.fw.hermes.service.biz.AppUpdateBizService;
import cn.fw.hermes.service.biz.MessageQueryerService;
import cn.fw.hermes.service.biz.MsgPrepareBizService;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * 消息debug类
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息debug类
 * @date : 2023-07-25 09:35
 */
@Validated
@RestController
@RequestMapping("/debug/msg")
@RequiredArgsConstructor
@Authorization(AuthType.NONE)
public class MsgDebugController {
    private final MessageQueryerService messageQueryerService;
    private final MsgPrepareBizService msgPrepareBizService;
    private final AppUpdateBizService appUpdateBizService;

    @ControllerMethod("发送一条测试消息")
    @PostMapping("/send")
    public Message<Void> sendMsg(@RequestBody MsgDebugDTO condition) {
        msgPrepareBizService.debugSendMsg(condition);
        return success();
    }

    @ControllerMethod("发送一条app更新消息")
    @PostMapping("/update")
    public Message<Void> sendUpdateMsg(@RequestParam("versionCode") Integer versionCode, @RequestParam("force") Boolean force) {
        appUpdateBizService.sendDebugUpdateMsg(versionCode, force);
        return success();
    }

    @ControllerMethod("查询消息发送状态")
    @GetMapping("/detail")
    public Message<MessageDetail> queryMsgStatus(@RequestParam("messageId") Long messageId) {
        MessageDetail messageDetail = messageQueryerService.queryDetailById(messageId);
        return success(messageDetail);
    }

    @ControllerMethod("查询消息内容")
    @GetMapping("/body")
    public Message<List<MessageBody>> queryMsgBody(@RequestParam("messageId") Long messageId) {
        List<MessageBody> list = messageQueryerService.queryMsgBodyByMsgId(messageId);
        return success(list);
    }
}
