package cn.fw.hermes.controller.erp;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.data.base.domain.common.Message;
import cn.fw.hermes.domain.dto.PlatformDTO;
import cn.fw.hermes.domain.dto.TopicDTO;
import cn.fw.hermes.domain.vo.MsgBizTypeVO;
import cn.fw.hermes.domain.vo.PlatformVO;
import cn.fw.hermes.domain.vo.TopicVO;
import cn.fw.hermes.service.biz.CommonBizService;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * 系统配置
 *
 * @author Kurisu
 * @date 2023-07-20
 */
@Validated
@RestController
@RequestMapping("/debug/sys")
@RequiredArgsConstructor
@Authorization(AuthType.NONE)
public class SysDebugController {
    private final CommonBizService commonBizService;

    @ControllerMethod("获取所有主题")
    @GetMapping("/topic/all")
    public Message<List<TopicVO>> getTopics() {
        List<TopicVO> list = commonBizService.queryTopics();
        return success(list);
    }

    @ControllerMethod("获取所有平台")
    @GetMapping("/platform/all")
    public Message<List<PlatformVO>> getPlatforms() {
        List<PlatformVO> list = commonBizService.queryPlatforms();
        return success(list);
    }

    @ControllerMethod("获取所有自定义消息的业务类型")
    @GetMapping("/msg/type/all")
    public Message<List<MsgBizTypeVO>> getMsgBizTypes() {
        List<MsgBizTypeVO> list = commonBizService.queryMsgBizTypes();
        return success(list);
    }

    @ControllerMethod("新增或修改平台")
    @PostMapping("/platform/save")
    public Message<Void> savePlatform(@RequestBody @Valid PlatformDTO dto) {
        commonBizService.savePlatform(dto);
        return success();
    }

    @ControllerMethod("新增或修改主题")
    @PostMapping("/topic/save")
    public Message<Void> saveTopic(@RequestBody @Valid TopicDTO dto) {
        commonBizService.saveTopic(dto);
        return success();
    }

    @ControllerMethod("新增自定义消息的业务类型")
    @PostMapping("/msg/type/save")
    public Message<Void> saveMsgBizType(@RequestParam("type") String type, @RequestParam("typeDesc") String typeDesc) {
        commonBizService.saveMsgBizType(type, typeDesc);
        return success();
    }

    @ControllerMethod("重连mqtt服务器")
    @PostMapping("/client/reconnect")
    public Message<Boolean> reconnect() {
        return success(commonBizService.reconnect());
    }

    @ControllerMethod("模拟发送预警消息")
    @PostMapping("/send/warning/msg")
    public Message<Void> sendWarningMsg() {
        commonBizService.debugSendWarningMsg();
        return success();
    }
}
