package cn.fw.hermes.config

import cn.fw.common.util.logInfo
import cn.fw.hermes.service.property.MqttProperty
import cn.fw.hermes.service.property.SettingProperty
import cn.fw.hermes.service.property.XinGeProperty
import cn.hutool.core.util.IdUtil
import com.tencent.xinge.XingeApp
import org.eclipse.paho.client.mqttv3.MqttAsyncClient
import org.eclipse.paho.client.mqttv3.MqttException
import org.eclipse.paho.client.mqttv3.persist.MemoryPersistence
import org.springframework.boot.context.properties.EnableConfigurationProperties
import org.springframework.cloud.context.config.annotation.RefreshScope
import org.springframework.context.annotation.Bean
import org.springframework.context.annotation.Configuration

/**
 * mqtt配置
 *
 * @author kurisu
 */
@RefreshScope
@Configuration
@EnableConfigurationProperties(MqttProperty::class, SettingProperty::class, XinGeProperty::class)
class AutoConfiguration(private val mqttProperty: MqttProperty, private val xinGeProperty: XinGeProperty) {
    @get:Throws(MqttException::class)
    @get:Bean
    val mqttClient: MqttAsyncClient
        get() {
            val host = mqttProperty.host
            val port = mqttProperty.port
            val nextId = IdUtil.simpleUUID()
            val clientId = String.format("%s-%s", mqttProperty.clientId, nextId)
            val url = String.format("%s:%d", host, port)
            logInfo("mqtt client initialize : {}", url)
            return MqttAsyncClient(url, clientId, MemoryPersistence())
        }

    @get:Bean
    val xingeClient: XingeApp
        get() {
            return XingeApp.Builder()
                .appId(xinGeProperty.appId)
                .secretKey(xinGeProperty.secretKey)
                .domainUrl(xinGeProperty.domainUrl)
                .build()

        }
}
