package cn.fw.hermes.config

import cn.fw.common.util.logError
import cn.fw.hermes.service.biz.CommonBizService
import cn.fw.hermes.service.emqx.MqttService
import com.github.yitter.contract.IdGeneratorOptions
import com.github.yitter.idgen.YitIdHelper
import org.springframework.beans.factory.DisposableBean
import org.springframework.boot.CommandLineRunner
import org.springframework.stereotype.Component

/**
 * @author: Kurisu
 * @date: 2021/2/4 9:13
 */
@Component
class LaunchConfiguration(
    private val commonBizService: CommonBizService,
    private val mqttService: MqttService
) : CommandLineRunner, DisposableBean {
    override fun run(vararg args: String) {
        try {
            //全局初始化设置WorkerId，默认最大2^16-1，可通过调整 WorkerIdBitLength 增加最大值
            val options = IdGeneratorOptions()
            options.WorkerId = 1
            options.WorkerIdBitLength = 3
            YitIdHelper.setIdGenerator(options)
            commonBizService.initSysData()
            mqttService.initialization()
        } catch (e: Exception) {
            logError("初始化系统信息失败", e)
        }
    }

    override fun destroy() {
        mqttService.disconnect()
    }
}
