package cn.fw.hermes.controller.api

import cn.fw.common.businessvalidator.Validator.BV
import cn.fw.common.web.annotation.ControllerMethod
import cn.fw.common.web.util.ResultBuilder.success
import cn.fw.data.base.domain.common.Message
import cn.fw.hermes.domain.enums.AccountTypeEnum
import cn.fw.hermes.sdk.v2.enums.AccountType
import cn.fw.hermes.sdk.v2.para.AccountV2Condition
import cn.fw.hermes.sdk.v2.service.IAccountV2Service
import cn.fw.hermes.service.biz.AccountBizService
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation.*

/**
 * 账号服务
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 账号服务
 * @date : 2023-07-20 16:51
 */
@Validated
@RestController
@RequestMapping("/api/hermes/account")
class AccountV2ServiceImpl(private val accountBizService: AccountBizService) : IAccountV2Service {
    @PostMapping("/register")
    @ControllerMethod("用户注册")
    override fun register(@RequestBody @Validated condition: AccountV2Condition): Message<Boolean> {
        val userId = condition.userId
        val userName = condition.userName
        val accountType = AccountType.ofValue(condition.accountType)
        if (AccountType.B_USER == accountType) {
            accountBizService.queryStaffTopic(userId, userName, "")
        } else {
            accountBizService.queryUserTopic(userId, userName, "")
        }
        return success(true)
    }

    @GetMapping("/getIdentifier")
    @ControllerMethod("获取用户标识码")
    override fun getIdentifier(@RequestParam("userId") userId: Long, @RequestParam(value = "userType", defaultValue = "1", required = false) userType: Int): Message<String> {
        val accountType = AccountType.ofValue(userType)
        BV.notNull(accountType) { "账户类型不正确" }
        val type = if (AccountType.B_USER == accountType) AccountTypeEnum.B_USER else AccountTypeEnum.C_USER
        val identifier = accountBizService.getUserIdentifier(userId, type)
        return success(identifier)
    }

    @GetMapping("/kick-out")
    @ControllerMethod("踢下线")
    override fun kick(@RequestParam("userId") userId: Long, @RequestParam("userType") userType: Int): Message<Void> {
        val accountType = AccountType.ofValue(userType)
        BV.notNull(accountType) { "账户类型不正确" }
        accountBizService.kick(userId, AccountType.B_USER == accountType)
        return success()
    }
}
