package cn.fw.hermes.controller.api.v2

import cn.fw.common.web.annotation.ControllerMethod
import cn.fw.common.web.util.ResultBuilder.success
import cn.fw.data.base.domain.common.Message
import cn.fw.hermes.sdk.v2.para.AppUpdateMsgCondition
import cn.fw.hermes.sdk.v2.para.MsgV2Condition
import cn.fw.hermes.sdk.v2.result.MessageV2Result
import cn.fw.hermes.sdk.v2.service.IMessageV2Service
import cn.fw.hermes.service.biz.AppUpdateBizService
import cn.fw.hermes.service.biz.MessageQueryerService
import cn.fw.hermes.service.biz.MsgPrepareBizService
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation.*

/**
 * 消息处理服务
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息处理服务
 * @date : 2023-07-22 15:05
 */
@RestController
@Validated
@RequestMapping("/api/hermes/message")
class MessageV2ServiceImpl(
    private val messageQueryerService: MessageQueryerService,
    private val msgPrepareBizService: MsgPrepareBizService,
    private val appUpdateBizService: AppUpdateBizService
) : IMessageV2Service {
    @PostMapping("/send/async")
    @ControllerMethod("异步发送消息")
    override fun asyncSendMsg(@RequestBody @Validated condition: MsgV2Condition): Message<Long> {
        return success(msgPrepareBizService.asyncSendMsg(condition))
    }

    @PostMapping("/send/sync")
    @ControllerMethod("同步发送消息")
    override fun sendMsg(@RequestBody @Validated condition: MsgV2Condition): Message<MessageV2Result> {
        return success(msgPrepareBizService.sendMsg(condition))
    }

    @GetMapping("/result")
    @ControllerMethod("查询消息结果")
    override fun queryMsgResult(@RequestParam("messageId") messageId: Long): Message<MessageV2Result> {
        return success(messageQueryerService.queryResultById(messageId))
    }

    @ControllerMethod("发送应用更新消息")
    @PostMapping("/send/update_msg")
    override fun sendUpdateMsg(@RequestBody @Validated condition: AppUpdateMsgCondition): Message<Void> {
        appUpdateBizService.sendUpdateMsg(condition)
        return success()
    }
}
