package cn.fw.hermes.controller.app

import cn.fw.common.web.annotation.ControllerMethod
import cn.fw.common.web.auth.annotation.CurrentUser
import cn.fw.common.web.util.ResultBuilder
import cn.fw.data.base.domain.common.Message
import cn.fw.hermes.domain.enums.AccountTypeEnum
import cn.fw.hermes.service.biz.XgPushService
import cn.fw.security.auth.client.annotation.Authorization
import cn.fw.security.auth.client.annotation.IgnoreAuth
import cn.fw.security.auth.client.enums.AuthType
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RequestParam
import org.springframework.web.bind.annotation.RestController

/**
 * 信鸽相关控制器
 *
 * @author : kurisu
 * @version : 1.0
 * @desc : 信鸽相关控制器
 * @date : 2024-01-05 18:08
 */
@Validated
@RestController
@RequestMapping("/app/xinge")
@Authorization(AuthType.APP)
class XgController(private val xgPushService: XgPushService) {

    @IgnoreAuth
    @ControllerMethod("绑定信鸽token")
    @PostMapping("/bind")
    fun bindToken(@CurrentUser userId: Long?, @RequestParam("xgToken") xgToken: String?): Message<Void> {
        xgPushService.saveUserToken(userId, AccountTypeEnum.B_USER, xgToken!!)
        return ResultBuilder.success()
    }

    @IgnoreAuth
    @ControllerMethod("解绑信鸽token")
    @PostMapping("/unbind")
    fun unbindToken(@CurrentUser userId: Long?): Message<Void> {
        xgPushService.delUserToken(userId, AccountTypeEnum.B_USER)
        return ResultBuilder.success()
    }
}
