package cn.fw.hermes.controller.common


import cn.fw.common.web.annotation.ControllerMethod
import cn.fw.common.web.util.ResultBuilder.success
import cn.fw.data.base.domain.common.Message
import cn.fw.hermes.domain.enums.AccountTypeEnum
import cn.fw.hermes.domain.xinge.XinGeProfile
import cn.fw.hermes.service.biz.XgPushService
import cn.fw.hermes.service.property.XinGeProperty
import cn.fw.security.auth.client.annotation.Authorization
import cn.fw.security.auth.client.enums.AuthType
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation.GetMapping
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RequestParam
import org.springframework.web.bind.annotation.RestController
import javax.validation.constraints.NotNull

/**
 * 信鸽debug类
 *
 * @author : kurisu
 * @version : 1.0
 * @desc : 信鸽debug类
 * @date : 2023-12-29 16:43
 */
@Validated
@RestController
@RequestMapping("/debug/xinge")
@Authorization(AuthType.NONE)
class XinGeDebugController(private val xinGeProperty: XinGeProperty, private val xgPushService: XgPushService) {
    @ControllerMethod("信鸽token绑定测试")
    @GetMapping("/token/bind")
    fun bind(
        @NotNull(message = "用户id不能为空") userId: Long?,
        @RequestParam(value = "accountType", defaultValue = "1", required = false) accountType: Int?,
        @NotNull(message = "信鸽token不能为空") xToken: String?
    ): Message<Void> {
        xToken?.let { xgPushService.saveUserToken(userId, AccountTypeEnum.ofValue(accountType), it) }
        return success()
    }

    @ControllerMethod("信鸽token解绑测试")
    @GetMapping("/token/unbind")
    fun unbind(@NotNull(message = "用户id不能为空") userId: Long?, @RequestParam(value = "accountType", defaultValue = "1", required = false) accountType: Int?): Message<Void> {
        userId?.let { xgPushService.delUserToken(it, AccountTypeEnum.ofValue(accountType)) }
        return success()
    }


    @get:ControllerMethod("获取信鸽相关配置")
    @get:GetMapping("/property/info")
    val xgProfile: Message<XinGeProfile>
        get() = success(xinGeProperty.run {
            XinGeProfile(appId, secretKey, connectTimeOut, readTimeOut, domainUrl)
        })
}
