package cn.fw.hermes.service.biz;

import cn.fw.hermes.domain.db.DisturbSetting;
import cn.fw.hermes.domain.dto.DisturbSettingDTO;
import cn.fw.hermes.domain.vo.DisturbSettingVO;
import cn.fw.hermes.service.data.DisturbSettingService;
import cn.fw.hermes.service.property.SettingProperty;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import java.time.LocalTime;
import java.util.Objects;

/**
 * 勿扰设置服务
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 勿扰设置服务
 * @date : 2023-07-27 15:09
 */
@Slf4j
@Service
@RequiredArgsConstructor
public class DisturbBizService {
    private final DisturbSettingService disturbSettingService;
    private final SettingProperty settingProperty;

    /**
     * 查询用户勿扰设置
     *
     * @param userId       用户id
     * @param platformCode 平台码
     */
    public DisturbSettingVO querySetting(Long userId, String platformCode) {
        DisturbSetting setting = disturbSettingService.queryByUserPlatform(userId, platformCode);
        if (Objects.isNull(setting)) {
            setting = disturbSettingService.init(userId, platformCode, settingProperty.getStart(),
                settingProperty.getEnd());
        }
        DisturbSettingVO vo = new DisturbSettingVO();
        BeanUtils.copyProperties(setting, vo);
        vo.setId(setting.getId());
        return vo;
    }

    /**
     * 修改设置
     *
     * @param userId       用户id
     * @param platformCode 平台码
     * @param setting      设置
     */
    public void saveUserSetting(Long userId, String platformCode, DisturbSettingDTO setting) {
        DisturbSetting db = new DisturbSetting();
        db.setUserId(userId);
        db.setPlatformCode(platformCode);
        db.setId(setting.getId());
        Boolean enabled = setting.getEnabled();
        if (Objects.nonNull(enabled)) {
            db.setEnabled(enabled);
        }
        LocalTime startTime = setting.getStartTime();
        if (Objects.nonNull(startTime)) {
            db.setStartTime(startTime);
        }
        LocalTime endTime = setting.getEndTime();
        if (Objects.nonNull(endTime)) {
            db.setEndTime(endTime);
        }
        disturbSettingService.updateById(db);
    }
}
