package cn.fw.hermes.service.biz;

import cn.fw.hermes.domain.db.MessageHistory;
import cn.fw.hermes.service.data.MessageDataService;
import cn.fw.hermes.service.data.MessageHistoryService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.time.LocalDate;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 历史消息管理服务
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 历史消息管理服务
 * @date : 2023-07-25 17:24
 */
@RequiredArgsConstructor
@Slf4j
@Service
public class MessageManaBizService {
    private final MessageHistoryService messageHistoryService;
    private final MessageDataService messageDataService;

    /**
     * 删除指定时间之前的历史消息
     *
     * @param deadline 截止日期
     */
    @Transactional(rollbackFor = Exception.class)
    public void removeHistoryMsg(LocalDate deadline) {
        List<MessageHistory> list = messageHistoryService.list(Wrappers.<MessageHistory>lambdaQuery()
                .le(MessageHistory::getCreateTime, deadline)
                .last(" limit 10000 ")
        );
        if (CollectionUtils.isEmpty(list)) {
            return;
        }
        List<Long> msgIds = list.stream().map(MessageHistory::getId).collect(Collectors.toList());
        messageHistoryService.removeByIds(msgIds);
        messageDataService.removeByMsgIds(msgIds);
    }
}
