package cn.fw.hermes.service.biz;

import cn.fw.hermes.common.utils.DateUtil;
import cn.fw.hermes.domain.db.MessageData;
import cn.fw.hermes.domain.db.MessageHistory;
import cn.fw.hermes.domain.vo.MessageBody;
import cn.fw.hermes.domain.vo.MessageDetail;
import cn.fw.hermes.sdk.v2.enums.MsgState;
import cn.fw.hermes.sdk.v2.result.MessageV2Result;
import cn.fw.hermes.service.data.MessageDataService;
import cn.fw.hermes.service.data.MessageHistoryService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * 消息查询器
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息查询器
 * @date : 2023-07-22 15:22
 */
@RequiredArgsConstructor
@Slf4j
@Service
public class MessageQueryerService {
    private final MessageHistoryService messageHistoryService;
    private final MessageDataService messageDataService;

    /**
     * 通过消息id查询消息处理状态
     *
     * @param messageId 消息id
     * @return
     */
    public MessageV2Result queryResultById(final Long messageId) {
        MessageHistory history = messageHistoryService.getById(messageId);
        BV.notNull(history, () -> "消息id有误");
        MessageV2Result result = new MessageV2Result();
        result.setMessageId(history.getId());
        MsgState msgState = BeanTransfer.trans2SdkMsgState(history.getMsgStatus());
        result.setMsgState(msgState.getValue());
        result.setMsgStateDesc(history.getMsgStatusDesc());
        result.setResultTime(DateUtil.toDate(history.getSendTime()));
        return result;
    }

    /**
     * 通过消息id查询消息处理状态
     *
     * @param messageId 消息id
     * @return
     */
    public MessageDetail queryDetailById(final Long messageId) {
        MessageHistory history = messageHistoryService.getById(messageId);
        BV.notNull(history, () -> "消息id有误");
        MessageDetail result = new MessageDetail();
        BeanUtils.copyProperties(history, result);
        result.setId(history.getId());
        return result;
    }

    /**
     * 通过消息id查询消息内容
     *
     * @param messageId
     * @return
     */
    public List<MessageBody> queryMsgBodyByMsgId(final Long messageId) {
        List<MessageBody> list = new ArrayList<>();
        List<MessageData> dataList = messageDataService.queryDataByMsgId(messageId);
        for (MessageData messageData : dataList) {
            MessageBody body = new MessageBody();
            BeanUtils.copyProperties(messageData, body);
            body.setId(messageData.getId());
            list.add(body);
        }
        return list;
    }
}
