package cn.fw.hermes.service.data.impl;

import cn.fw.hermes.common.constant.Constant;
import cn.fw.hermes.dao.mapper.DisturbSettingMapper;
import cn.fw.hermes.domain.db.DisturbSetting;
import cn.fw.hermes.service.data.DisturbSettingService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.lang.Nullable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalTime;

/**
 * 勿扰设置服务
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 勿扰设置服务
 * @date : 2023-07-27 15:08
 */
@Service
public class DisturbSettingServiceImpl extends ServiceImpl<DisturbSettingMapper, DisturbSetting>
    implements DisturbSettingService {
    /**
     * 根据用户和平台查询勿扰设置
     *
     * @param userId   用户id
     * @param platform 平台码
     * @return
     */
    @Override
    @Nullable
    @Cacheable(cacheNames = Constant.DISTURB_SETTING_CACHE_KEY, key = "#platform+':'+#userId", unless = "#result == null ")
    public DisturbSetting queryByUserPlatform(final Long userId, final String platform) {
        return this.getOne(Wrappers.<DisturbSetting>lambdaQuery()
            .eq(DisturbSetting::getUserId, userId)
            .eq(DisturbSetting::getPlatformCode, platform), Boolean.FALSE);
    }

    /**
     * 初始化一个设置
     *
     * @param userId    用户id
     * @param platform  平台码
     * @param startTime 开始时间
     * @param endTime   结束时间
     * @return
     */
    @Override
    public DisturbSetting init(final Long userId, final String platform, final LocalTime startTime,
                               final LocalTime endTime) {
        DisturbSetting db = new DisturbSetting();
        db.setUserId(userId);
        db.setPlatformCode(platform);
        db.setEnabled(Boolean.TRUE);
        db.setStartTime(startTime);
        db.setEndTime(endTime);
        DisturbSetting setting = this.getOne(Wrappers.<DisturbSetting>lambdaQuery()
            .eq(DisturbSetting::getUserId, userId)
            .eq(DisturbSetting::getPlatformCode, platform), Boolean.FALSE);
        if (setting == null) {
            this.save(db);
            return db;
        }
        return setting;
    }

    /**
     * 根据 ID 选择修改
     *
     * @param setting 实体对象
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    @CacheEvict(cacheNames = Constant.DISTURB_SETTING_CACHE_KEY, key = "#setting.platformCode+':'+#setting.userId", condition = "#setting.id != null")
    public boolean updateById(DisturbSetting setting) {
        return super.updateById(setting);
    }
}
