package cn.fw.hermes.service.data.impl;

import cn.fw.hermes.common.constant.Constant;
import cn.fw.hermes.dao.mapper.HermesMapper;
import cn.fw.hermes.domain.db.Hermes;
import cn.fw.hermes.domain.dto.HermesDTO;
import cn.fw.hermes.domain.enums.AccountTypeEnum;
import cn.fw.hermes.service.data.HermesService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Objects;

/**
 * 账号信息
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 账号信息
 * @date : 2023-06-21 15:51
 */
@Service
public class HermesServiceImpl extends ServiceImpl<HermesMapper, Hermes> implements HermesService {
    @Cacheable(cacheNames = Constant.ACCOUNT_CACHE_KEY, key = "#userId+':'+#type.name()", unless = "#result == null ")
    @Override
    public Hermes queryByUserId(Long userId, AccountTypeEnum type) {
        return getOne(Wrappers.<Hermes>lambdaQuery()
                .eq(Hermes::getUserId, userId)
                .eq(Hermes::getAccountType, type)
            , Boolean.FALSE);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    @CacheEvict(cacheNames = Constant.ACCOUNT_CACHE_KEY, key = "#dto.userId+':'+#dto.accountType.name()", condition = "#dto.id != null")
    public void saveByDto(HermesDTO dto) {
        Hermes db = new Hermes();
        BeanUtils.copyProperties(dto, db);
        db.setId(db.getId());
        if (Objects.nonNull(db.getId())) {
            db.setIdentifier(null);
            db.setCreateDay(null);
        }
        saveOrUpdate(db);
    }
}
