package cn.fw.hermes.service.data.impl;

import cn.fw.hermes.dao.mapper.MessageDataMapper;
import cn.fw.hermes.domain.db.MessageData;
import cn.fw.hermes.service.data.MessageDataService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 消息体信息
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息体信息
 * @date : 2023-06-21 15:51
 */
@Service
public class MessageDataServiceImpl extends ServiceImpl<MessageDataMapper, MessageData> implements MessageDataService {
    @Override
    public List<MessageData> queryDataByMsgId(Long msgId) {
        List<MessageData> dataList = this.list(Wrappers.<MessageData>lambdaQuery()
                .eq(MessageData::getMsgId, msgId)
        );
        if (dataList == null) {
            return Collections.emptyList();
        }
        return dataList;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void removeByMsgIds(List<Long> msgIds) {
        List<MessageData> dataList = list(Wrappers.<MessageData>lambdaQuery()
                .in(MessageData::getMsgId, msgIds)
        );
        if (CollectionUtils.isEmpty(dataList)) {
            return;
        }
        List<Long> idList = dataList.stream().map(MessageData::getId).collect(Collectors.toList());
        removeByIds(idList);
    }
}
