package cn.fw.hermes.service.data.impl;

import cn.fw.hermes.common.utils.DateUtil;
import cn.fw.hermes.dao.mapper.MessageHistoryMapper;
import cn.fw.hermes.domain.db.MessageHistory;
import cn.fw.hermes.domain.enums.MsgStatusEnum;
import cn.fw.hermes.sdk.v2.enums.MsgState;
import cn.fw.hermes.sdk.v2.result.MessageV2Result;
import cn.fw.hermes.service.data.MessageHistoryService;
import cn.fw.hermes.service.mq.MessageProducer;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.Objects;

/**
 * 消息记录
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息记录
 * @date : 2023-06-21 15:51
 */
@Service
public class MessageHistoryServiceImpl extends ServiceImpl<MessageHistoryMapper, MessageHistory> implements MessageHistoryService {
    private final MessageProducer messageProducer;

    @Autowired
    public MessageHistoryServiceImpl(final MessageProducer messageProducer) {
        this.messageProducer = messageProducer;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean updateById(MessageHistory history) {
        return super.updateById(history);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void sendCallback(Long id, boolean success, String desc) {
        MessageHistory history = getById(id);
        if (Objects.isNull(history)) {
            return;
        }
        history.setMsgStatus(success ? MsgStatusEnum.SUCCESS : MsgStatusEnum.FAIL);
        history.setMsgStatusDesc(desc);
        if (success) {
            history.setSendSuccessTime(LocalDateTime.now());
        }
        if (Boolean.TRUE.equals(history.getNeedResult())) {
            MessageV2Result result = new MessageV2Result();
            result.setMessageId(id);
            MsgState msgState = success ? MsgState.SUCCESS : MsgState.FAIL;
            result.setMsgState(msgState.getValue());
            result.setMsgStateDesc(history.getMsgStatusDesc());
            result.setResultTime(DateUtil.toDate(LocalDateTime.now()));
            messageProducer.send(result);
        }
        updateById(history);
    }
}
