package cn.fw.hermes.service.data.impl;

import cn.fw.hermes.common.constant.Constant;
import cn.fw.hermes.dao.mapper.SysPlatformMapper;
import cn.fw.hermes.domain.db.SysPlatform;
import cn.fw.hermes.domain.dto.PlatformDTO;
import cn.fw.hermes.domain.enums.PlatformTypeEnum;
import cn.fw.hermes.service.data.SysPlatformService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * 系统平台
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 系统平台
 * @date : 2023-06-21 15:45
 */
@Service
public class SysPlatformServiceImpl extends ServiceImpl<SysPlatformMapper, SysPlatform> implements SysPlatformService {

    @Override
    @Cacheable(cacheNames = Constant.PLATFORM_CACHE_KEY, key = "'platform'", unless = "#result.isEmpty()")
    public List<SysPlatform> queryPlatforms() {
        List<SysPlatform> list = this.list();
        if (CollectionUtils.isEmpty(list)) {
            return new ArrayList<>();
        }
        return list;
    }

    @Override
    public SysPlatform queryPlatformByType(PlatformTypeEnum platformTypeEnum) {
        return this.getOne(Wrappers.<SysPlatform>lambdaQuery()
                .eq(SysPlatform::getPlatformType, platformTypeEnum), Boolean.FALSE);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    @CacheEvict(cacheNames = Constant.PLATFORM_CACHE_KEY, allEntries = true)
    public void modifyAndAdd(PlatformDTO platform) {
        SysPlatform db = new SysPlatform();
        db.setId(platform.getId());
        db.setPlatformCode(platform.getPlatformCode());
        db.setPlatformName(platform.getPlatformName());
        db.setPlatformType(PlatformTypeEnum.ofValue(platform.getPlatformType()));
        if (db.getId() == null) {
            this.save(db);
            return;
        }
        this.updateById(db);
    }
}
