package cn.fw.hermes.service.data.impl;

import cn.fw.hermes.common.constant.Constant;
import cn.fw.hermes.dao.mapper.SysTopicMapper;
import cn.fw.hermes.domain.db.SysTopic;
import cn.fw.hermes.domain.dto.TopicDTO;
import cn.fw.hermes.service.data.SysTopicService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * 系统主题信息
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 系统主题信息
 * @date : 2023-06-21 15:45
 */
@Service
public class SysTopicServiceImpl extends ServiceImpl<SysTopicMapper, SysTopic> implements SysTopicService {

    @Override
    @Cacheable(cacheNames = Constant.TOPIC_CACHE_KEY, key = "'topic'", unless = "#result.isEmpty()")
    public List<SysTopic> queryTopics() {
        List<SysTopic> list = this.list(Wrappers.<SysTopic>lambdaQuery()
                .eq(SysTopic::getYn, Boolean.TRUE)
                .eq(SysTopic::getPreset, Boolean.FALSE)
        );
        if (CollectionUtils.isEmpty(list)) {
            return new ArrayList<>();
        }
        return list;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    @CacheEvict(cacheNames = Constant.TOPIC_CACHE_KEY, allEntries = true)
    public void modifyAndAdd(TopicDTO topicDTO) {
        SysTopic db = new SysTopic();
        BeanUtils.copyProperties(topicDTO, db);
        db.setId(topicDTO.getId());
        if (db.getId() == null) {
            db.setYn(Boolean.TRUE);
            this.save(db);
            return;
        }
        this.updateById(db);
    }
}
