package cn.fw.hermes.service.mq;

import cn.fw.hermes.sdk.v2.result.MessageV2Result;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.rocketmq.spring.core.RocketMQTemplate;
import org.springframework.lang.NonNull;
import org.springframework.stereotype.Component;

/**
 * 消息结果mq通知
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息结果mq
 * @date : 2023-06-21 15:52
 */
@Slf4j
@Component
@RequiredArgsConstructor
public class MessageProducer {
    private static final String TAG = "消息结果MQ";
    private final RocketMQTemplate rocketMQTemplate;

    public void send(@NonNull MessageV2Result result) {
        try {
            log.info("{} : body [{}]", TAG, result);
            rocketMQTemplate.syncSend(MessageV2Result.TOPIC, result);
        } catch (Exception e) {
            log.error("{} 消息结果发送失败 messageId[{}]", TAG, result.getMessageId());
        }
    }
}
